module GrowViral
  module Keystore
    class AccountFetcher
      def self.fetch(*args)
        new(*args).fetch
      end

      def self.exists?(*args)
        new(*args).exists?
      end

      attr_reader :application_id, :uid, :config
      def initialize(application_id, uid, deps)
        raise HandleNotUidError unless uid.is_a? Numeric

        @application_id = application_id
        @uid = uid
        @config = deps[:config]
      end

      def exists?
        fetch
      rescue GrowViral::NoAccountError
        false
      end

      def fetch
        response = Net::HTTP.get_response(uri)
        if response.code.to_i == 200
          Account.new JSON.parse(response.body)
        else
          raise GrowViral::NoAccountError.new(uid)
        end
      end

      def uri
        @uri ||= URI.parse("#{config.host}/applications/#{application_id}/accounts/#{uid}")
      end
    end
  end
end
